DioClient class

Constructors

DioClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

multipartRequest(String url, {required FormData formData, RequestMethod method = RequestMethod.post, AuthToken authToken = AuthToken.multipartNone, bool isLogUpload = true}) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited