MobigicLogger class

Constructors

MobigicLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

allowLogging bool
Controlled by app OR --dart-define
getter/setter pair

Static Methods

clearLogs() Future<void>
Clears the plain-text log file contents (keeps the file)
copyLogTo(File destFile) Future<File?>
Copies the current plain-text log file to destFile (useful for export) Example usage from UI: copyTo(File('/storage/emulated/0/Download/mobigic_export.txt'))
debug(Object log) Future<void>
ensureInitialized() Future<void>
error(Object log, {Object? error, StackTrace? stackTrace}) Future<void>
getLogFilePath() Future<String?>
info(Object log) Future<void>
openLogFile() Future<OpenResult?>
Opens the plain-text log file with the platform default viewer. Returns the OpenResult from open_file.
readAllLogs() Future<String>
Reads the whole plain-text log into a string (useful to show in-app)
warning(Object log) Future<void>
wtf(Object log) Future<void>

Constants

subTag → const String
tag → const String