didChangeAppLifecycleState method

  1. @override
void didChangeAppLifecycleState(
  1. AppLifecycleState state
)
override

Called when the system puts the app in the background or returns the app to the foreground.

An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.

This method exposes notifications from SystemChannels.lifecycle.

See also:

Implementation

@override
void didChangeAppLifecycleState(AppLifecycleState state) {
  if (state == AppLifecycleState.resumed && _forceUpdatePending) {
    if (!_isDialogVisible) {
      Future.delayed(const Duration(milliseconds: 500), () {
        final ctx = _lastContext;
        if (ctx != null && ctx.mounted) {
          _showForceUpdateDialog(ctx);
        }
      });
    }
  }
}